calender_merger
===============

Merge calenders and import them into your calender.

[**Try it out**](https://calender-merger.herokuapp.com/)

Heroku 
------

.. image:: https://www.herokucdn.com/deploy/button.svg
   :target: https://heroku.com/deploy?template=https://github.com/avinassh/niccokunzmann/calender_merger
   :alt: Deploy to Heroku

Status
------
   
.. image:: https://travis-ci.org/niccokunzmann/calender_merger.svg
   :target: https://travis-ci.org/niccokunzmann/calender_merger
   :alt: Build Status